pub enum GrpcMessageAction {
Forward(GrpcMessage),
Drop,
Error(u32, String),
}Expand description
Actions a middleware can take after intercepting a gRPC message.
Variants
Forward(GrpcMessage)
Forward the message along the processing chain. It can be potentially modified.
Drop
Silently drop the message, meaning it won’t reach its intended destination.
Error(u32, String)
Return an immediate gRPC error to the client with the specified status code and message.