pub enum GrpcDirection {
ClientToUpstream,
UpstreamToClient,
}Expand description
Defines the direction of the gRPC message stream.
Variants
ClientToUpstream
Request flowing from the client to the upstream server.
UpstreamToClient
Response flowing from the upstream server back to the client.